@@ -14,7 +14,7 @@ app.command()(mod.main)
 def test_call_no_arg():
     result = runner.invoke(app)
     assert result.exit_code != 0
-    assert 'Error: Missing argument "NAME".' in result.output
+    assert "Error: Missing argument 'NAME'." in result.output
 
 
 def test_call_arg():
