@@ -11,7 +11,7 @@ runner = CliRunner()
 def test_no_arg():
     result = runner.invoke(app)
     assert result.exit_code != 0
-    assert 'Error: Missing argument "NAME".' in result.output
+    assert "Error: Missing argument 'NAME'." in result.output
 
 
 def test_arg():
