@@ -22,7 +22,7 @@ def test_invalid_uuid():
     result = runner.invoke(app, ["7479706572-72756c6573"])
     assert result.exit_code != 0
     assert (
-        'Error: Invalid value for "USER_ID": 7479706572-72756c6573 is not a valid UUID value'
+        "Error: Invalid value for 'USER_ID': 7479706572-72756c6573 is not a valid UUID value"
         in result.output
     )
 
