@@ -128,7 +128,7 @@ COMPLETION_SCRIPT_ZSH = """
 compdef %(complete_func)s %(prog_name)s
 """
 
-COMPLETION_SCRIPT_FISH = 'complete --command %(prog_name)s --no-files --arguments "(env %(autocomplete_var)s=complete_fish _TYPER_COMPLETE_FISH_ACTION=get-args _TYPER_COMPLETE_ARGS=(commandline -cp) %(prog_name)s)" --condition "env %(autocomplete_var)s=complete_fish _TYPER_COMPLETE_FISH_ACTION=is-args _TYPER_COMPLETE_ARGS=(commandline -cp) %(prog_name)s'
+COMPLETION_SCRIPT_FISH = 'complete --command %(prog_name)s --no-files --arguments "(env %(autocomplete_var)s=complete_fish _TYPER_COMPLETE_FISH_ACTION=get-args _TYPER_COMPLETE_ARGS=(commandline -cp) %(prog_name)s)" --condition "env %(autocomplete_var)s=complete_fish _TYPER_COMPLETE_FISH_ACTION=is-args _TYPER_COMPLETE_ARGS=(commandline -cp) %(prog_name)s"'
 
 COMPLETION_SCRIPT_POWER_SHELL = """
 Import-Module PSReadLine
@@ -166,7 +166,7 @@ def install(
         shell, _ = shellingham.detect_shell()
     mode = None
     if shell == "bash":
-        path_obj = Path.home() / ".bash_completion"
+        path_obj = Path.home() / ".bashrc"
         mode = mode or "a"
     elif shell == "zsh":
         path_obj = Path.home() / ".zshrc"
@@ -221,11 +221,11 @@ def install(
 
 def get_installable_script(prog_name: str, complete_var: str, shell: str) -> str:
     if shell == "bash":
-        return f'eval "$({complete_var}=source_bash {prog_name})"'
+        return f'eval "$({complete_var}=source_bash {prog_name} 2>/dev/null)"'
     elif shell == "zsh":
-        return f'eval "$({complete_var}=source_zsh {prog_name})"'
+        return f'eval "$({complete_var}=source_zsh {prog_name} 2>/dev/null)"'
     elif shell == "fish":
-        return f"eval (env {complete_var}=source_fish {prog_name})"
+        return f"eval (env {complete_var}=source_fish {prog_name} 2>/dev/null)"
     elif shell in {"powershell", "pwsh"}:
         return get_completion_script(prog_name, complete_var, shell)
     return ""
